searchData={"items":[{"type":"module","title":"CompoundFile","doc":"A library for reading and writing Microsoft Compound File Binary Format (CFBF) files, also known\nas Composite Document File v2 (CDF).\n\nThis module provides functions to create and read CFBF documents.\n\nSee `CompoundFile.Writer` for documentation on creating documents, and `CompoundFile.Reader` for\nreading existing documents.","ref":"CompoundFile.html"},{"type":"module","title":"Example - CompoundFile","doc":"iex> alias CompoundFile.{Reader, Writer}\n    iex>\n    iex> {:ok, binary} =\n    iex>   Writer.new()\n    iex>   |> Writer.add_file(\"example.txt\", \"Hello, World!\")\n    iex>   |> Writer.render()\n    iex>\n    iex> {:ok, [entry]} = Reader.files(binary)\n    iex>\n    iex> Reader.file_data(binary, entry)\n    {:ok, \"Hello, World!\"}","ref":"CompoundFile.html#module-example"},{"type":"module","title":"CompoundFile.Debug","doc":"Debugging utilities for the Compound File structure.\n\nUsed while developing and testing the library, but kept in case you'd like to inspect the\ninternals of a compound file.","ref":"CompoundFile.Debug.html"},{"type":"function","title":"CompoundFile.Debug.dump_chain/2","doc":"","ref":"CompoundFile.Debug.html#dump_chain/2"},{"type":"function","title":"CompoundFile.Debug.dump_sector/2","doc":"","ref":"CompoundFile.Debug.html#dump_sector/2"},{"type":"function","title":"CompoundFile.Debug.hexdump/2","doc":"","ref":"CompoundFile.Debug.html#hexdump/2"},{"type":"function","title":"CompoundFile.Debug.print_header/1","doc":"","ref":"CompoundFile.Debug.html#print_header/1"},{"type":"module","title":"CompoundFile.Reader","doc":"Reader for Compound File Binary (CFB) formatted files.\n\nThis module is in its infancy, and will respond to errors in the file by crashing.  If you are\ngoing to use this module, please assume that some point in the future these functions will\nreturn `{:error, reason}` instead of crashing.\n\nIt is also very, very slow working with large files.\n\nPlease contribute to the project if you'd like to use this module in production!","ref":"CompoundFile.Reader.html"},{"type":"function","title":"CompoundFile.Reader.file_data/2","doc":"Get the data of a file by using its file entry.\n\nNote that passing invalid CFB files to this function will result in an exception or unpredictable behavior.\n\nYou can get a file entry by calling `CompoundFile.Reader.files/1`.\n\nReturns `{:ok, binary}` with the file data.","ref":"CompoundFile.Reader.html#file_data/2"},{"type":"function","title":"CompoundFile.Reader.files/1","doc":"List all files in a compound file.\n\nNote that passing invalid CFB files to this function will result in an exception or unpredictable behavior.\n\nReturns `{:ok, [FileEntry.t()]}` with a list of file entries.\n\nUse `CompoundFile.Reader.file_data/2` to get the data from a file entry.","ref":"CompoundFile.Reader.html#files/1"},{"type":"module","title":"CompoundFile.Reader.FileEntry","doc":"Represents a file entry in a Microsoft Compound File Binary Format (CFBF) document.\n\nThis module is used by `CompoundFile.Reader` to represent files within the compound file.","ref":"CompoundFile.Reader.FileEntry.html"},{"type":"type","title":"CompoundFile.Reader.FileEntry.t/0","doc":"","ref":"CompoundFile.Reader.FileEntry.html#t:t/0"},{"type":"module","title":"CompoundFile.Writer","doc":"Creates a Compound File Document (CFD) in the Microsoft Compound File Binary Format (CFBF).\n\nThis module allows you to create a new document, add streams and storages, and render the final\nbinary representation of the document.","ref":"CompoundFile.Writer.html"},{"type":"module","title":"Example usage - CompoundFile.Writer","doc":"iex> alias CompoundFile.Writer\n    iex>\n    iex> Writer.new()\n    iex> |> Writer.add_file(\"example.txt\", \"Hello, World!\")\n    iex> |> Writer.add_file(\"data/text/example2.txt\", \"Another file\")\n    iex> |> Writer.render()\n\nThis will create a new Compound File Document with the following files:\n\n  - `/example.txt`\n  - `/data/text/example2.txt`","ref":"CompoundFile.Writer.html#module-example-usage"},{"type":"function","title":"CompoundFile.Writer.add_file/3","doc":"Adds a file to the Compound File Document.\n\nIf the directory structure specified in the `path` does not exist, directories (storage objects)\nwill be created as needed. The file will then be added as a stream object.\n\nReturns the updated document.","ref":"CompoundFile.Writer.html#add_file/3"},{"type":"function","title":"CompoundFile.Writer.add_storage/3","doc":"Adds a storage object (directory) to the Compound File Document.\n\nThis function creates a new storage entry in the document. The storage object can be used to group\nfiles (stream objects) together. The `parent` parameter specifies the parent storage object ID, or\n`nil` for the root directory. The `filename` is the name of the storage object.\n\nReturns a tuple of the updated document and the object ID of the new storage object.","ref":"CompoundFile.Writer.html#add_storage/3"},{"type":"function","title":"CompoundFile.Writer.add_stream/4","doc":"Adds a stream object to the Compound File Document.\n\nThis function is used to add a binary stream to the document.  The stream object is added to the\neither the root directory (when `parent` is `nil`) or to the specified parent directory (by\npassing the storage object's ID as `parent`).\n\nReturns the updated document.","ref":"CompoundFile.Writer.html#add_stream/4"},{"type":"function","title":"CompoundFile.Writer.new/0","doc":"Initialises a new, empty Compound File Document.","ref":"CompoundFile.Writer.html#new/0"},{"type":"function","title":"CompoundFile.Writer.render/1","doc":"Renders the Compound File Document to a binary format.\n\nReturns `{:ok, binary()}` containing the complete binary representation of the document.\nYou can write this binary to a file or use it as needed.","ref":"CompoundFile.Writer.html#render/1"},{"type":"module","title":"CompoundFile.Writer.Document","doc":"Represents a Microsoft Compound File Binary Format (CFBF) document.\n\nCreate a new document with `CompoundFile.Writer.new/0`, and add stream and storage objects using\nthe `CompoundFile.Writer` module.","ref":"CompoundFile.Writer.Document.html"},{"type":"type","title":"CompoundFile.Writer.Document.t/0","doc":"","ref":"CompoundFile.Writer.Document.html#t:t/0"},{"type":"module","title":"CompoundFile.Writer.Object","doc":"Represents a storage or stream object in a Microsoft Compound File Binary Format (CFBF) document.\n\nCreate a new object with `CompoundFile.Writer.add_stream/4` or `CompoundFile.Writer.add_storage/3`.","ref":"CompoundFile.Writer.Object.html"},{"type":"type","title":"CompoundFile.Writer.Object.t/0","doc":"","ref":"CompoundFile.Writer.Object.html#t:t/0"},{"type":"extras","title":"CompoundFile","doc":"# CompoundFile\n\nCompoundFile is an Elixir library for reading and writing Compound File Binary Format (CFBF) files, also known as\nCompound Document format, Composite Document File V2, or OLE2.0 files.","ref":"readme.html"},{"type":"extras","title":"Installation - CompoundFile","doc":"Add `compound_file` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:compound_file, \"~> 0.1\"}\n  ]\nend\n```\n\nThen, run `mix deps.get` to install the dependency.","ref":"readme.html#installation"},{"type":"extras","title":"Usage - CompoundFile","doc":"Constructing a CFBF file might look something like this:\n\n```elixir\nalias CompoundFile.Writer\n\nWriter.new()\n|> Writer.add_file(\"example.txt\", \"Hello, World!\")\n|> Writer.add_file(\"data/text/example2.txt\", \"Another file\")\n|> Writer.render()\n|> case do\n  {:ok, binary} ->\n    File.write!(\"example.cfbf\", binary)\n\n  {:error, reason} ->\n    IO.puts(\"Error writing CFBF file: #{reason}\")\nend\n```\n\nReading a CFBF file can be performed like this:\n\n```elixir\nalias CompoundFile.Reader\n\nbinary = File.read!(\"example.cfbf\")\n\n{:ok, [file_entry | _]} = Reader.files(binary)\n{:ok, content} = Reader.file_data(binary, file_entry)\n\nIO.puts(\"First filename: #{file_entry.path}\")\nIO.puts(\"First file content: #{content}\")\n```","ref":"readme.html#usage"},{"type":"extras","title":"Maturity - CompoundFile","doc":"This library is in an early stage of development. File writing is relatively stable, but reading does not have\nany error handling yet. Please contribute if you find bugs or have suggestions for improvements.","ref":"readme.html#maturity"},{"type":"extras","title":"Contributing - CompoundFile","doc":"Contributions are welcome! Please open an issue or submit a pull request on GitHub.","ref":"readme.html#contributing"},{"type":"extras","title":"License - CompoundFile","doc":"MIT license, copyright 2025- Mog Nesbitt.","ref":"readme.html#license"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.38.2"}}